/*
 * TMK Alps64 PCB
 */
KEYBOARD_ID = "alps64";
KEYBOARD_DESC = "TMK Alps64 PCB"

/* for ATMega32U4 with 32KB flash */
KEYMAP_START_ADDRESS = 0x6800;

/* https://github.com/tmk/tmk_keyboard/tree/master/keyboard/alps64
 *
 * Default keymap
 * ,-----------------------------------------------------------.
 * |`  |  1|  2|  3|  4|  5|  6|  7|  8|  9|  0|  -|  =|  #|Bsp|
 * |-----------------------------------------------------------|
 * |Tab  |  Q|  W|  E|  R|  T|  Y|  U|  I|  O|  P|  [|  ]|  \  |
 * |-----------------------------------------------------------|
 * |Caps  |  A|  S|  D|  F|  G|  H|  J|  K|  L|  ;|  '|Enter   |
 * |-----------------------------------------------------------|
 * |Shft|  \|  Z|  X|  C|  V|  B|  N|  M|  ,|  .|  /|Shift |Esc|
 * |-----------------------------------------------------------'
 * |Ctrl|Gui |Alt |         Space         |App |Alt |Gui |Ctrl |
 * `-----------------------------------------------------------'
 */
no_map = function() { return [
    [0,0,0,0,0,0,0,0],
    [0,0,0,0,0,0,0,0],
    [0,0,0,0,0,0,0,0],
    [0,0,0,0,0,0,0,0],
    [0,0,0,0,0,0,0,0],
    [0,0,0,0,0,0,0,0],
    [0,0,0,0,0,0,0,0],
    [0,0,0,0,0,0,0,0],
]; };
transparent_map = function() { return [
    [1,1,1,1,1,1,1,1],
    [1,1,1,1,1,1,1,1],
    [1,1,1,1,1,1,1,1],
    [1,1,1,1,1,1,1,1],
    [1,1,1,1,1,1,1,1],
    [1,1,1,1,1,1,1,1],
    [1,1,1,1,1,1,1,1],
    [1,1,1,1,1,1,1,1],
]; };

// default keymap
keymaps = [
    [
        [ 0xE6, 0x10, 0x36, 0x0E, 0x0F, 0x12, 0x27, 0x2D, ],
        [ 0xE7, 0x37, 0x38, 0x33, 0x34, 0x13, 0x2F, 0x2E, ],
        [ 0xE4, 0xE5, 0x29, 0x28, 0x31, 0x30, 0x32, 0x2A, ],
        [ 0xE0, 0xE1, 0x39, 0x04, 0x2B, 0x14, 0x35, 0x1E, ],
        [ 0xE3, 0x64, 0x1D, 0x16, 0x1A, 0x08, 0x1F, 0x20, ],
        [ 0xE2, 0x1B, 0x07, 0x09, 0x15, 0x17, 0x21, 0x22, ],
        [ 0x2C, 0x06, 0x19, 0x0A, 0x1C, 0x18, 0x23, 0x24, ],
        [ 0x65, 0x05, 0x11, 0x0B, 0x0D, 0x0C, 0x25, 0x26, ],
    ],
    transparent_map(),
    transparent_map(),
    transparent_map(),
    transparent_map(),
    transparent_map(),
    transparent_map(),
    transparent_map(),
];

fn_actions = [
    0xF1,0xA1,0xF1,0xA2,0xF1,0xA3,0xF1,0xA4,
    0xF1,0xA5,0xF1,0xA6,0xF1,0xA7,0x02,0x8A,
    0x04,0x8A,0x08,0x8A,0xF0,0xA1,0xF0,0xA2,
    0xF0,0xA3,0x31,0xA1,0x2B,0xA2,0x28,0xA3,
    0x2C,0xA4,0x33,0xA5,0x34,0xA6,0x38,0xA7,
    0x2C,0x22,0x2C,0x21,0x34,0x31,0x28,0x31,
    0x29,0x21,0x2A,0x21,0x00,0x21,0x29,0x22,
    0x2A,0x22,0x00,0x22,0x35,0x32,0x31,0x32,
];

/* Fn actions source */
fn_actions_source = "\
    [0]  = ACTION_LAYER_MOMENTARY(1),\n\
    [1]  = ACTION_LAYER_MOMENTARY(2),\n\
    [2]  = ACTION_LAYER_MOMENTARY(3),\n\
    [3]  = ACTION_LAYER_MOMENTARY(4),\n\
    [4]  = ACTION_LAYER_MOMENTARY(5),\n\
    [5]  = ACTION_LAYER_MOMENTARY(6),\n\
    [6]  = ACTION_LAYER_MOMENTARY(7),\n\
    [7]  = ACTION_LAYER_TOGGLE(1),\n\
    [8]  = ACTION_LAYER_TOGGLE(2),\n\
    [9]  = ACTION_LAYER_TOGGLE(3),\n\
    [10] = ACTION_LAYER_TAP_TOGGLE(1),\n\
    [11] = ACTION_LAYER_TAP_TOGGLE(2),\n\
    [12] = ACTION_LAYER_TAP_TOGGLE(3),\n\
    [13] = ACTION_LAYER_TAP_KEY(1, KC_BSLASH),\n\
    [14] = ACTION_LAYER_TAP_KEY(2, KC_TAB),\n\
    [15] = ACTION_LAYER_TAP_KEY(3, KC_ENTER),\n\
    [16] = ACTION_LAYER_TAP_KEY(4, KC_SPACE),\n\
    [17] = ACTION_LAYER_TAP_KEY(5, KC_SCOLON),\n\
    [18] = ACTION_LAYER_TAP_KEY(6, KC_QUOTE),\n\
    [19] = ACTION_LAYER_TAP_KEY(7, KC_SLASH),\n\
    [20] = ACTION_MODS_TAP_KEY(MOD_LSFT, KC_SPACE),\n\
    [21] = ACTION_MODS_TAP_KEY(MOD_LCTL, KC_SPACE),\n\
    [22] = ACTION_MODS_TAP_KEY(MOD_RCTL, KC_QUOTE),\n\
    [23] = ACTION_MODS_TAP_KEY(MOD_RCTL, KC_ENTER),\n\
    [24] = ACTION_MODS_TAP_KEY(MOD_LCTL, KC_ESC),\n\
    [25] = ACTION_MODS_TAP_KEY(MOD_LCTL, KC_BSPACE),\n\
    [26] = ACTION_MODS_ONESHOT(MOD_LCTL),\n\
    [27] = ACTION_MODS_TAP_KEY(MOD_LSFT, KC_ESC),\n\
    [28] = ACTION_MODS_TAP_KEY(MOD_LSFT, KC_BSPACE),\n\
    [29] = ACTION_MODS_ONESHOT(MOD_LSFT),\n\
    [30] = ACTION_MODS_TAP_KEY(MOD_RSFT, KC_GRAVE),\n\
    [31] = ACTION_MODS_TAP_KEY(MOD_RSFT, KC_BSLASH),\n\
";


/* hex file whthout keymap region and eof */
function firmware_hex()
{
    /*  Flash Map of ATMega32U2(32KB)
     *  +------------+ 0x0000
     *  | .vectors   | 0xac (43vectors * 4bytes)
     *  | .progmem   | PROGMEM variables and PSTR
     *  | .init0-9   |
     *  | .text      | code
     *  | .fini9-0   |
     *  |            | > text region
     *  |------------| _etext
     *  | .data      |
     *  | .bss       |
     *  | .noinit    |
     *  |            | > data region
     *  |------------| 0x6800
     *  | .keymap    | > keymap region(2KB)
     *  |------------| 0x7000
     *  | bootloader | 4KB
     *  +------------+ 0x7FFF
     *
     *  keymap region(.keymap):
     *  +----------------+
     *  | fn_actions[]   | 64 byte
     *  |----------------|
     *  |                |
     *  | keymaps[][][]  | < 2KB-64
     *  |                |
     *  +----------------+
     */
    // TODO: read hex file directly from remote URL
    // Place HEX format string of firmware(0x0000-0x67ff) excluding keymap region.
    return "\
:100000000C942D050C9471050C9471050C947105DC\r\n\
:100010000C9471050C9471050C9471050C94710588\r\n\
:100020000C9471050C9471050C9471050C94400CA2\r\n\
:100030000C94EE0C0C94071C0C9471050C94710537\r\n\
:100040000C9471050C9471050C9471050C946E1C44\r\n\
:100050000C9471050C9471050C9471050C94710548\r\n\
:100060000C9471050C9471050C9471050C94710538\r\n\
:100070000C947105860689068C068F0692069506F5\r\n\
:100080009806530D750D600E750D600EB70DDA0DE7\r\n\
:10009000600E2F0E420E73117311A111A111FD11EB\r\n\
:1000A00039122A142A1451122A144813481304141A\r\n\
:1000B0002A142A1418140A002530313662003A2016\r\n\
:1000C0000025303258000A722F6320303132333429\r\n\
:1000D00035363738394142434445460A000A00253F\r\n\
:1000E00030325800626F756E6365213A20005B7391\r\n\
:1000F0005D004B6579626F61726420737461727424\r\n\
:100100002E0A0055534220636F6E666967757265EB\r\n\
:10011000642E0A005B525D005B445D005B435D0042\r\n\
:100120000E0341006C0070007300360034000000C4\r\n\
:10013000080354004D004B000000040309040902A9\r\n\
:100140007400040100A03209040000010301010051\r\n\
:10015000092111010001223F000705810308000A5F\r\n\
:10016000090401000103010200092111010001221B\r\n\
:100170004D000705820308000A090402000103007C\r\n\
:100180000000092111010001223600070583030840\r\n\
:10019000000A090403000203000000092111010004\r\n\
:1001A0000122200007058403200001070504032025\r\n\
:1001B00000011201100100000008EDFE646401005E\r\n\
:1001C000010200010631FF0974A10109751500251E\r\n\
:1001D000FF9520750881020976150025FF95207589\r\n\
:1001E000089102C005010980A101850216010026BF\r\n\
:1001F000B7001A01002AB700751095018100C005EB\r\n\
:100200000C0901A1018503160100269C021A0100B8\r\n\
:100210002A9C02751095018100C005010902A10107\r\n\
:100220000901A100050919012905150025019505F8\r\n\
:1002300075018102950175038101050109300931BC\r\n\
:100240001581257F95027508810609381581257F5E\r\n\
:10025000950175088106050C0A38021581257F95E0\r\n\
:100260000175088106C0C005010906A1010507192D\r\n\
:10027000E029E715002501950875018102950175B2\r\n\
:100280000881010508190129059505750191029557\r\n\
:1002900001750391010507190029FF150025FF9538\r\n\
:1002A0000675088100C00A002530325820006B65B1\r\n\
:1002B00079626F6172645F7265706F72743A200068\r\n\
:1002C0000A0025303258006B6579626F6172645F95\r\n\
:1002D0007365745F6C65643A2000646F6E652E0A06\r\n\
:1002E00000626F6F676D61676963207363616E3A67\r\n\
:1002F000202E2E2E2000290A002575002F0025759E\r\n\
:10030000005D28002564002000256400200025648D\r\n\
:100310000020002564007C0025303258006D6F7588\r\n\
:1003200073656B6579205B62746E7C7820792076CA\r\n\
:1003300020685D287265702F61636C293A205B002C\r\n\
:100340006D6B5F776865656C5F74696D655F746F11\r\n\
:100350005F6D6178203D2025640A006D6B5F7768D2\r\n\
:1003600065656C5F6D61785F7370656564203D20C5\r\n\
:1003700025640A006D6B5F74696D655F746F5F6DF6\r\n\
:100380006178203D2025640A006D6B5F6D61785FA8\r\n\
:100390007370656564203D2025640A006D6B5F699C\r\n\
:1003A0006E74657276616C203D2025640A006D6B69\r\n\
:1003B0005F64656C6179203D2025640A006D6B5F88\r\n\
:1003C000776865656C5F74696D655F746F5F6D619B\r\n\
:1003D00078203D2025640A006D6B5F776865656C49\r\n\
:1003E0005F6D61785F7370656564203D2025640AE8\r\n\
:1003F000006D6B5F74696D655F746F5F6D61782010\r\n\
:100400003D2025640A006D6B5F6D61785F737065D8\r\n\
:100410006564203D2025640A006D6B5F696E74651C\r\n\
:100420007276616C203D2025640A006D6B5F646507\r\n\
:100430006C6179203D2025640A000A00257500368C\r\n\
:100440003A20776865656C5F74696D655F746F5F8E\r\n\
:100450006D61783A20000A00257500353A207768EA\r\n\
:1004600065656C5F6D61785F73706565643A2000E7\r\n\
:100470000A00257500343A2074696D655F746F5FFA\r\n\
:100480006D61783A20000A00257500333A206D61CD\r\n\
:10049000785F73706565643A20000A002575003244\r\n\
:1004A0003A20696E74657276616C286D73293A2002\r\n\
:1004B000000A00257500313A2064656C6179282AAC\r\n\
:1004C00031306D73293A20000A092D2056616C7570\r\n\
:1004D0006573202D0A004D3E004D25643E20003FEF\r\n\
:1004E000007365742064656661756C740A00433E30\r\n\
:1004F000200077686572652064656C74613A2063DA\r\n\
:100500007572736F723D25642C20776865656C3D4C\r\n\
:1005100025640A53656520687474703A2F2F656EE0\r\n\
:100520002E77696B6970656469612E6F72672F77CA\r\n\
:10053000696B692F4D6F7573655F6B6579730A0021\r\n\
:100540000A092D204D6F7573656B6579202D0A455D\r\n\
:1005500053432F713A09717569740A313A09646518\r\n\
:100560006C6179282A31306D73290A323A09696E33\r\n\
:1005700074657276616C286D73290A333A096D616E\r\n\
:10058000785F73706565640A343A0974696D655FF4\r\n\
:10059000746F5F6D61780A353A09776865656C5FDD\r\n\
:1005A0006D61785F73706565640A363A09776865CE\r\n\
:1005B000656C5F74696D655F746F5F6D61780A0A61\r\n\
:1005C000703A097072696E742076616C7565730A91\r\n\
:1005D000643A097365742064656661756C74730AA6\r\n\
:1005E00075703A092B310A646F776E3A092D310A1A\r\n\
:1005F000706775703A092B31300A7067646F776ED7\r\n\
:100600003A092D31300A0A7370656564203D206413\r\n\
:10061000656C7461202A206D61785F737065656414\r\n\
:10062000202A2028726570656174202F2074696DFE\r\n\
:10063000655F746F5F6D6178290A003F004D3E2051\r\n\
:1006400000433E20004C25640A000A092D20436F18\r\n\
:100650006E736F6C65202D0A4553432F713A0971F3\r\n\
:100660007569740A6D3A096D6F7573656B65790A02\r\n\
:10067000000A092D204D61676963202D0A643A093B\r\n\
:1006800064656275670A783A096465627567206D0A\r\n\
:1006900061747269780A6B3A096465627567206BE8\r\n\
:1006A0006579626F6172640A6D3A096465627567A3\r\n\
:1006B000206D6F7573650A763A0976657273696F96\r\n\
:1006C0006E0A733A097374617475730A633A096345\r\n\
:1006D0006F6E736F6C65206D6F64650A302D343AF0\r\n\
:1006E000096C61796572302D34284631302D4634DD\r\n\
:1006F000290A506175733A09626F6F746C6F616497\r\n\
:1007000065720A653A09656570726F6D0A000A00C4\r\n\
:100710002575002E6E6B726F3A20000A0025750059\r\n\
:100720002E737761705F6261636B736C6173685F76\r\n\
:100730006261636B73706163653A20000A0025751E\r\n\
:10074000002E737761705F67726176655F657363B2\r\n\
:100750003A20000A002575002E6E6F5F6775693AB2\r\n\
:1007600020000A002575002E737761705F72616C3E\r\n\
:10077000745F726775693A20000A002575002E7350\r\n\
:100780007761705F6C616C745F6C6775693A2000AB\r\n\
:100790000A002575002E636170736C6F636B5F7464\r\n\
:1007A0006F5F636F6E74726F6C3A20000A0025757C\r\n\
:1007B000002E737761705F636F6E74726F6C5F632E\r\n\
:1007C0006170736C6F636B3A20000A0025303258F9\r\n\
:1007D000006B65796D61705F636F6E6669672E721D\r\n\
:1007E00061773A20000A002575002E6D6F757365DC\r\n\
:1007F0003A20000A002575002E6B6579626F6172E0\r\n\
:10080000643A20000A002575002E6D6174726978C3\r\n\
:100810003A20000A002575002E656E61626C653A0B\r\n\
:1008200020000A00253032580064656275675F63F6\r\n\
:100830006F6E6669672E7261773A20000A0025752F\r\n\
:100840000064656661756C745F6C617965723A20ED\r\n\
:10085000003F0074696D65725F636F756E743A2056\r\n\
:100860002530346C580A006B6579626F6172645F81\r\n\
:1008700069646C653A2025580A006B6579626F617E\r\n\
:1008800072645F70726F746F636F6C3A2025580AE0\r\n\
:1008900000686F73745F6B6579626F6172645F6C1F\r\n\
:1008A00065647328293A2025580A000A092D205327\r\n\
:1008B0007461747573202D0A004743433A20342E27\r\n\
:1008C000382E31204156522D4C4942433A20312E88\r\n\
:1008D000382E3073766E204156525F415243483A6B\r\n\
:1008E0002061767233350A004F5054494F4E533AC7\r\n\
:1008F000204C55464120424F4F544D4147494320DB\r\n\
:100900004D4F5553454B45592045585452414B4541\r\n\
:100910005920434F4E534F4C4520434F4D4D414E70\r\n\
:1009200044204B45594D41505F53454354494F4E28\r\n\
:1009300020343039360A004255494C443A20376455\r\n\
:1009400036323161632D6469727479202831363A08\r\n\
:1009500034333A3134204A616E2031312032303123\r\n\
:1009600036290A005649443A2030784645454428FD\r\n\
:10097000544D4B29205049443A203078363436348F\r\n\
:1009800028416C7073363429205645523A2030780D\r\n\
:10099000303030310A00444553433A20544D4B2007\r\n\
:1009A0006B6579626F617264206669726D776172DE\r\n\
:1009B0006520666F7220416C707336340A000A0934\r\n\
:1009C0002D2056657273696F6E202D0A000A6D6FB7\r\n\
:1009D0007573653A206F66660A000A6D6F757365F8\r\n\
:1009E0003A206F6E0A000A6B6579626F6172643A31\r\n\
:1009F000206F66660A000A6B6579626F6172643AFD\r\n\
:100A0000206F6E0A000A6D61747269783A206F6611\r\n\
:100A1000660A000A6D61747269783A206F6E0A0086\r\n\
:100A20000A64656275673A206F6E0A000A6465623F\r\n\
:100A300075673A206F66660A000A0A626F6F746C07\r\n\
:100A40006F616465722E2E2E2000433E2000656586\r\n\
:100A5000636F6E6669673A0A000011241FBECFEF0C\r\n\
:100A6000D4E0DEBFCDBF04B603FE24C08091CA012E\r\n\
:100A70009091CB01A091CC01B091CD018730904BEA\r\n\
:100A8000A740B04BB9F41092CA011092CB0110925A\r\n\
:100A9000CC011092CD0114BE84B7877F84BF88E15A\r\n\
:100AA0000FB6F89480936000109260000FBEE0E0F3\r\n\
:100AB000F8E3099511E0A0E0B1E0E6E7FFE402C049\r\n\
:100AC00005900D92A233B107D9F721E0A2E3B1E07E\r\n\
:100AD00001C01D92AA3CB207E1F70E948A090C945A\r\n\
:100AE000B9270C940000FF93EF93E0913201F0914D\r\n\
:100AF0003301309709F00995EF91FF910895FC01BA\r\n\
:100B00008591803011F0EFDFFBCF0895FF27E0E201\r\n\
:100B100030E247FF0CC0419597FF09C0EDE26095B8\r\n\
:100B2000709580959095611D711D811D911D27FF08\r\n\
:100B300002C0219530E350E2AA27660F771F881F75\r\n\
:100B4000991FAA1FA41710F0A41B63955A95A9F723\r\n\
:100B5000AA3008F0A95FA05DAF93F3956115710508\r\n\
:100B60008105910541F7ED3211F4EF93F395F217FA\r\n\
:100B700018F43F93F395FBCF8F91B5DFFA95E1F72A\r\n\
:100B80000895E991F9918591803021F0853219F02D\r\n\
:100B9000AADFF9CF089520E0E89455915532C1F3CA\r\n\
:100BA000503311F4689455915A3348F4505390F3EC\r\n\
:100BB000220F022E220F220F200D250FF4CF0EF44C\r\n\
:100BC000219589919991533619F3533729F153356A\r\n\
:100BD00059F1BC0188279927E8945C3621F4899162\r\n\
:100BE000999168945591543639F446EF7EF077FF29\r\n\
:100BF0000DC08FEF9FEF0AC055374AE039F05835E6\r\n\
:100C000040E121F0523642E009F00895FF93EF935E\r\n\
:100C10007DDFEF91FF91B7CFFF93EF93FC018191BF\r\n\
:100C20008030B9F360DFFBCFFF93EF9368DFF1CF44\r\n\
:100C3000DF93CF93CDB7DEB72596A3DFCF91DF91BA\r\n\
:100C40000895E82FF0E083E0EE0FFF1F8A95E1F7AB\r\n\
:100C5000E70FF11D93E0EE0FFF1F9A95E1F7E60F06\r\n\
:100C6000F11DE05CF74984910895E82FF0E0EE0F64\r\n\
:100C7000FF1FE058F9498591949108958AB18078D1\r\n\
:100C80008AB98BB180788BB93A98429808950E94BE\r\n\
:100C90003E0684B114B885B18FEF85B9ECE3F1E07D\r\n\
:100CA000A4E3B1E011921D9221E0E434F207D1F700\r\n\
:100CB0008091AB0182608093AB013D9A459A8FEFA2\r\n\
:100CC00099E628E1815090402040E1F700C0000003\r\n\
:100CD0003D9845980895EF92FF920F931F93CF93FD\r\n\
:100CE000DF93C4E3D1E0F12C85E0E82E0FED10E0B6\r\n\
:100CF0008F2D90E0FC013197E730F10520F4E65CA0\r\n\
:100D0000FF4F0C946E27509A589814C0519A5998D6\r\n\
:100D100011C0529A5A980EC0539A5B980BC0549ABD\r\n\
:100D20005C9808C0559A5D9805C0569A5E9802C0B6\r\n\
:100D30003A9A429880EA8A95F1F783B18095988132\r\n\
:100D4000981739F1888380910001882301F18091FF\r\n\
:100D5000AB0180FF04C084EE90E00E947F0580918B\r\n\
:100D6000AB0180FF0CC0809100011F928F931F93F5\r\n\
:100D70000F930E9418060F900F900F900F90809184\r\n\
:100D8000AB0180FF04C08DED90E00E947F05E092F2\r\n\
:100D900000010E943E06F394219698E0F912A8CF34\r\n\
:100DA000809100018823B1F0815080930001882355\r\n\
:100DB00039F08FE99FE00197F1F700C000000AC009\r\n\
:100DC000ACE3B1E0E4E3F1E081918D9391E0EC33A9\r\n\
:100DD000F907D1F781E0DF91CF911F910F91FF903B\r\n\
:100DE000EF900895E82FF0E0E45CFE4F80810895D5\r\n\
:100DF000CF92DF92EF92FF920F931F93CF93DF93E7\r\n\
:100E000086EC90E00E947F059CE3E92E91E0F92EAC\r\n\
:100E1000C0E0D0E021ECC22E20E0D22E08EB10E0A2\r\n\
:100E2000DF93CF93DF92CF920E9418068EEB90E073\r\n\
:100E30000E947F05F70181917F0190E00E94B01B25\r\n\
:100E40009F938F931F930F930E94180686EB90E059\r\n\
:100E50000E947F0521968DB79EB708960FB6F8942D\r\n\
:100E60009EBF0FBE8DBFC830D105D1F6DF91CF91A7\r\n\
:100E70001F910F91FF90EF90DF90CF90089581FF29\r\n\
:100E800003C03D9A459A08953D98459808958091EC\r\n\
:100E90004F0108959FB7F894109246019FBF90911B\r\n\
:100EA000C101943009F058C09091E9009F702091E1\r\n\
:100EB000EC0020FF02C020E801C020E0292B94E0D4\r\n\
:100EC0009093E9009091EB0090FF43C09091EE0069\r\n\
:100ED00097FF3FC090914401992321F09091E80041\r\n\
:100EE00095FF37C01092440196E03091E80035FD3F\r\n\
:100EF00015C03091C101343061F53091EB0035FD02\r\n\
:100F000028C0915021F481E08093440122C0EFE990\r\n\
:100F1000FFE03197F1F700C00000E7CF8093F100C8\r\n\
:100F20008091E80085FD0AC08091E80080FFFCCF39\r\n\
:100F30008091E8008E778093E80006C08FB7F89420\r\n\
:100F400091E0909346018FBF2F702093E90080E0DD\r\n\
:100F500008952F702093E9008FEF0895CF93DF93CA\r\n\
:100F600000D01F92CDB7DEB72091C101243019F512\r\n\
:100F700023E029839B838A832093E9008FEF90915C\r\n\
:100F8000E800815095FD06C095ED9A95F1F70000B7\r\n\
:100F90008111F5CF8091E80085FF0DC040E050E061\r\n\
:100FA00063E070E0CE0101960E94470A8091E8005C\r\n\
:100FB0008E778093E8000F900F900F90DF91CF9184\r\n\
:100FC0000895CF93DF9300D01F92CDB7DEB7209165\r\n\
:100FD000C101243021F522E029839B838A8383E0A9\r\n\
:100FE0008093E9008FEF9091E800815095FD06C055\r\n\
:100FF00095ED9A95F1F700008111F5CF8091E80009\r\n\
:1010000085FF0DC040E050E063E070E0CE01019646\r\n\
:101010000E94470A8091E8008E778093E8000F9045\r\n\
:101020000F900F90DF91CF9108952091C10124304E\r\n\
:10103000F1F422E02093E9002FEF3091E8002150F5\r\n\
:1010400035FD06C035ED3A95F1F700002111F5CFD9\r\n\
:101050002091E80025FF0BC040E050E065E070E023\r\n\
:101060000E94470A8091E8008E778093E8000895F7\r\n\
:10107000CF93DF93EC018091C101843039F581E099\r\n\
:101080008093E9008FEF9091E800815095FD06C0B4\r\n\
:1010900095ED9A95F1F700008111F5CF8091E80068\r\n\
:1010A00085FF14C040E050E068E070E0CE010E948F\r\n\
:1010B000470A8091E8008E778093E80088E0FE017F\r\n\
:1010C000A7E4B1E001900D928A95E1F7DF91CF910D\r\n\
:1010D00008958CE191E00E947F058091C00181110B\r\n\
:1010E00009C00E94DD0B0E94300C8091E2008460F8\r\n\
:1010F0008093E200089588E191E00E947F051092BC\r\n\
:10110000C001089584E191E00C947F058091450130\r\n\
:101110008F5F8093450162E30E944E27911135C095\r\n\
:101120001092450180914601882379F18091C10197\r\n\
:10113000843049F58091E9008F709091EC0090FF28\r\n\
:1011400002C090E801C090E0982B84E08093E90011\r\n\
:101150008091EB0080FF14C08091EE0087FF10C0EB\r\n\
:101160008091E80085FF03C01092F100F9CF8091D3\r\n\
:10117000E80080FF05C08091E8008E778093E8004A\r\n\
:101180009F709093E90010924601089542E061EC4F\r\n\
:1011900081E00E94570B42E061EC82E00E94570B15\r\n\
:1011A00042E061EC83E00E94570B42E261EC84E094\r\n\
:1011B0000C94570B8091C301833009F453C030F471\r\n\
:1011C000813071F0823009F48CC008958A3009F4BE\r\n\
:1011D00078C08B3009F45EC0893009F09AC020C015\r\n\
:1011E0008091C201813A09F094C08091E800877F24\r\n\
:1011F0008093E8008091C6019091C701892B21F06E\r\n\
:1012000060E080E090E003C068E087E491E070E097\r\n\
:101210000E94900A8091E8008B778093E8000895FF\r\n\
:101220008091C201813209F074C08091C601909111\r\n\
:10123000C701892B09F06DC08091E800877F8093FA\r\n\
:10124000E8008091E80082FD05C08091C101811114\r\n\
:10125000F8CF5FC08091F10080934F018091E8004A\r\n\
:101260008B7753C08091C201813A09F052C08091BE\r\n\
:10127000C6019091C701892B09F04BC08091E8000D\r\n\
:10128000877F8093E8008091E80080FFFCCF809109\r\n\
:101290000B0136C08091C2018132D9F58091C6011F\r\n\
:1012A0009091C701892BA9F58091E800877F8093F1\r\n\
:1012B000E8000E948C0B8091C40180930B010C9478\r\n\
:1012C0004B148091C201813221F58091E800877F23\r\n\
:1012D0008093E8000E948C0B8091C501809350019F\r\n\
:1012E00008958091C201813AA1F48091E800877F3E\r\n\
:1012F0008093E8008091E80080FFFCCF809150014E\r\n\
:101300008093F1008091E8008E778093E8000C9440\r\n\
:101310008C0B089584B7877F84BF88E10FB6F8945B\r\n\
:1013200080936000109260000FBE90E080E80FB6DE\r\n\
:10133000F89480936100909361000FBE0E94060FA5\r\n\
:101340000E94DD0B0E94300C8091E200846080934B\r\n\
:10135000E2008AE497E00E949A1B78948091C10190\r\n\
:101360008430E1F783E091E00E947F050E94080F3E\r\n\
:1013700081E091E00E94780E82EF90E00E947F056C\r\n\
:101380008091C101853089F48EEE90E00E947F0546\r\n\
:101390000E94CA1B8091BF01882391F30E94F21B17\r\n\
:1013A000882371F30E94310AEBCF0E94360FE8CFF9\r\n\
:1013B000292F332723303105A9F06CF42130310572\r\n\
:1013C00009F442C02230310509F043C084E790E0BF\r\n\
:1013D0002EE331E042C021323105C9F0223231051D\r\n\
:1013E00019F137C099278130910541F0823091057C\r\n\
:1013F00041F0892B71F5EAE3F1E005C0E0E3F1E0AB\r\n\
:1014000002C0E0E2F1E0849190E09F0126C06430E8\r\n\
:1014100000F5E62FF0E0EE0FFF1FE05EFE4F2081AB\r\n\
:10142000318189E090E019C0643098F4E62FF0E053\r\n\
:10143000DF01AA0FBB1FA85EBE4F2D913C91EC5E51\r\n\
:10144000FE4F808190E009C082E190E022EB31E024\r\n\
:1014500004C080E090E020E030E0FA013183208396\r\n\
:10146000089584E089BD86E089BD09B400FEFDCF02\r\n\
:101470008091D8008F7D8093D8008091E0008260B9\r\n\
:101480008093E0008091E00081FDFCCF0895CF9231\r\n\
:10149000DF92EF92FF920F931F93CF93DF937C0124\r\n\
:1014A0008B01EA010E94AD0B811131C0209731F010\r\n\
:1014B00088819981081B190BE80EF91EC12CD12CCB\r\n\
:1014C0000115110519F18091E80085FD14C0809186\r\n\
:1014D000E8008E778093E800209741F08881998119\r\n\
:1014E0008C0D9D1D9983888385E011C00E94AD0BF2\r\n\
:1014F000882331F30CC0F70181917F018093F100C3\r\n\
:1015000001501109FFEFCF1ADF0ADACF80E0DF9137\r\n\
:10151000CF911F910F91FF90EF90DF90CF900895A2\r\n\
:101520002091C8013091C9012617370748F061158D\r\n\
:10153000710539F42091E8002E772093E80001C06E\r\n\
:10154000B90120E061157105D1F13091C10133235A\r\n\
:1015500009F443C0353009F442C03091E80033FD4E\r\n\
:1015600040C03091E80032FF06C08091E80082FF61\r\n\
:1015700029C080E008953091E80030FFE3CF20914A\r\n\
:10158000F20030E0FC01281B390BCF01820F931FC2\r\n\
:101590006115710549F08830910530F4819180938F\r\n\
:1015A000F10061507109F1CF21E0089709F020E0C6\r\n\
:1015B0008091E8008E778093E800CF01C3CF21119E\r\n\
:1015C000C4CFD3CF8091C101882339F0853039F061\r\n\
:1015D0008091E80083FFC9CF04C082E0089583E0D2\r\n\
:1015E000089581E008952091C8013091C90126171E\r\n\
:1015F000370748F06115710539F42091E8002E771E\r\n\
:101600002093E80001C0B90120E061157105D9F10E\r\n\
:101610003091C101332309F444C0353009F443C08B\r\n\
:101620003091E80033FD41C03091E80032FF06C040\r\n\
:101630008091E80082FF2AC080E008953091E800A0\r\n\
:1016400030FFE3CF2091F20030E0FC01281B390B82\r\n\
:10165000C9018E0F9F1F6115710551F088309105EA\r\n\
:1016600038F484918093F100319661507109F0CF84\r\n\
:1016700021E0089709F020E08091E8008E778093C0\r\n\
:10168000E800CF01C2CF2111C3CFD2CF8091C101D9\r\n\
:10169000882339F0853039F08091E80083FFC8CF86\r\n\
:1016A00004C082E0089583E0089581E00895982FB2\r\n\
:1016B000953058F59093E900981739F07091EC0047\r\n\
:1016C0002091ED005091F00003C0242F762F50E0C0\r\n\
:1016D00021FF19C03091EB003E7F3093EB00309139\r\n\
:1016E000ED003D7F3093ED003091EB0031603093A1\r\n\
:1016F000EB007093EC002093ED005093F0002091EC\r\n\
:10170000EE0027FF07C09F5FD3CF8F708093E90063\r\n\
:1017100081E0089580E008958091C20187FD05C0B1\r\n\
:101720008091E80080FF0EC012C08091E80082FD29\r\n\
:1017300005C08091C1018111F8CF08958091E80022\r\n\
:101740008B7708C08091C1018111EACF0895809103\r\n\
:10175000E8008E778093E80008958091E4009091EE\r\n\
:10176000E50045E62091EC0020FF21C02091E80033\r\n\
:1017700020FD21C02091C101222389F0253089F06C\r\n\
:101780002091EB0025FD0FC02091E4003091E50091\r\n\
:101790002817390739F3415041F0C901E3CF82E0FE\r\n\
:1017A000089583E0089581E0089584E008952091EC\r\n\
:1017B000E80022FFDFCF80E008950E943A0C0E94EB\r\n\
:1017C0003D0CE0EEF0E0808181608083E8EDF0E0A8\r\n\
:1017D00080818F77808319BCE3E6F0E080818160AF\r\n\
:1017E00080831092C00108950E943A0C0E943D0C23\r\n\
:1017F0008091D8008F778093D8008091D80080683E\r\n\
:101800008093D8008091D8008F7D8093D80084E0A9\r\n\
:1018100089BD86E089BD09B400FEFDCF1092C101EB\r\n\
:101820001092BD011092BF011092BE0142E060E033\r\n\
:1018300080E00E94570B8091E1008E7F8093E10051\r\n\
:101840008091E20081608093E2008091E2008860F4\r\n\
:101850008093E2008091E0008E7F8093E000089505\r\n\
:10186000E3E6F0E080818E7F808381E08093C00199\r\n\
:101870000C94F40B1092E20008951092E100089588\r\n\
:101880001F920F920FB60F9211242F933F934F93F5\r\n\
:101890005F936F937F938F939F93AF93BF93EF93D8\r\n\
:1018A000FF938091E10082FF0BC08091E20082FFF4\r\n\
:1018B00007C08091E1008B7F8093E1000E94860841\r\n\
:1018C0008091E10080FF18C08091E20080FF14C089\r\n\
:1018D0008091E2008E7F8093E2008091E20080613F\r\n\
:1018E0008093E2008091D80080628093D80019BC78\r\n\
:1018F0001092C1010E947B088091E10084FF30C0FA\r\n\
:101900008091E20084FF2CC084E089BD86E089BD1F\r\n\
:1019100009B400FEFDCF8091D8008F7D8093D80060\r\n\
:101920008091E1008F7E8093E1008091E2008F7EC4\r\n\
:101930008093E2008091E20081608093E2008091D8\r\n\
:10194000BD01882311F084E007C08091E30087FF88\r\n\
:1019500002C083E001C081E08093C1010E94690858\r\n\
:101960008091E10083FF29C08091E20083FF25C0C0\r\n\
:101970008091E100877F8093E10082E08093C10144\r\n\
:101980001092BD018091E1008E7F8093E1008091F3\r\n\
:10199000E2008E7F8093E2008091E200806180937C\r\n\
:1019A000E20042E060E080E00E94570B8091F0008E\r\n\
:1019B00088608093F0000E948208FF91EF91BF91B0\r\n\
:1019C000AF919F918F917F916F915F914F913F91D7\r\n\
:1019D0002F910F900FBE0F901F9018951F920F928E\r\n\
:1019E0000FB60F9211242F933F934F935F936F93F2\r\n\
:1019F0007F938F939F93AF93BF93CF93EF93FF9377\r\n\
:101A0000C091E900CF708091EC001092E9008091C4\r\n\
:101A1000F000877F8093F00078940E942A0D109246\r\n\
:101A2000E9008091F00088608093F000C093E900A5\r\n\
:101A3000FF91EF91CF91BF91AF919F918F917F9146\r\n\
:101A40006F915F914F913F912F910F900FBE0F902B\r\n\
:101A50001F9018951F93CF93DF93CDB7DEB7AA974A\r\n\
:101A60000FB6F894DEBF0FBECDBFE2ECF1E080917F\r\n\
:101A7000F100819321E0EA3CF207C9F70E94DA08FD\r\n\
:101A80008091E80083FF1CC12091C2013091C30105\r\n\
:101A9000832F90E08A30910508F012C1FC01EF5BC2\r\n\
:101AA000FF4F0C946E27203881F0223809F008C1CE\r\n\
:101AB0008091C6018F708093E9008091EB0085FBD7\r\n\
:101AC000882780F91092E90006C08091BE019091AC\r\n\
:101AD000BF01911182609091E800977F9093E80098\r\n\
:101AE0008093F1001092F100C5C0822F8D7F09F024\r\n\
:101AF000E7C0222319F0223061F0E2C08091C401D6\r\n\
:101B0000813009F0DDC0333009F080E08093BF01FF\r\n\
:101B100028C08091C401811124C02091C6012F707A\r\n\
:101B200009F4CEC02093E9008091EB0080FF19C03A\r\n\
:101B30008091EB00333011F4806211C0806180939A\r\n\
:101B4000EB0081E090E0022E01C0880F0A94EAF7D2\r\n\
:101B50008093EA001092EA008091EB008860809305\r\n\
:101B6000EB001092E9008091E800877F86C0211188\r\n\
:101B7000A7C01091C4011F778091E3008078812B6A\r\n\
:101B80008093E3008091E800877F8093E8000E94C3\r\n\
:101B90008C0B8091E80080FFFCCF8091E30080688F\r\n\
:101BA0008093E300112311F083E001C082E0809371\r\n\
:101BB000C10186C02058223008F082C08091C40143\r\n\
:101BC0009091C5018C3D23E0920779F583E08A83EB\r\n\
:101BD0008AE289834FB7F894DE01139620E03EE055\r\n\
:101BE00051E2E32FF0E050935700E49120FF03C04F\r\n\
:101BF000E295EF703F5FEF708E2F90E0EA3010F0CB\r\n\
:101C0000C79601C0C0968D939D932F5F243149F7ED\r\n\
:101C10004FBF8091E800877F8093E8006AE270E020\r\n\
:101C2000CE0101960E94900A14C0AE014F5F5F4F33\r\n\
:101C30006091C6010E94D809009709F441C0209123\r\n\
:101C4000E800277F2093E800BC0189819A810E94E7\r\n\
:101C5000F30A8091E8008B778093E80031C0203848\r\n\
:101C600079F58091E800877F8093E8008091BD013D\r\n\
:101C70008093F1008091E8008E778093E8000E94C5\r\n\
:101C80008C0B1EC021111CC09091C4019230C0F475\r\n\
:101C90008091E800877F8093E8009093BD010E94C7\r\n\
:101CA0008C0B8091BD01811104C08091E30087FFFE\r\n\
:101CB00002C084E001C081E08093C1010E94C60897\r\n\
:101CC0008091E80083FF0AC08091E800877F8093BD\r\n\
:101CD000E8008091EB0080628093EB00AA960FB63B\r\n\
:101CE000F894DEBF0FBECDBFDF91CF911F91089555\r\n\
:101CF00090935601809355010895E0915501F0911C\r\n\
:101D00005601309721F00190F081E02D099480E098\r\n\
:101D10000895FF920F931F93CF93DF938C01E0916F\r\n\
:101D20005501F0915601309799F10280F381E02D31\r\n\
:101D300009958091AB0182FF2BC080FF04C08EEA21\r\n\
:101D400092E00E947F05E80188E0F82E08EA12E0A0\r\n\
:101D50008091AB0180FF0BC088811F928F931F93EE\r\n\
:101D60000F930E9418060F900F900F900F90FA9407\r\n\
:101D70002196F110EDCF8091AB0180FF09C086EA7A\r\n\
:101D800092E0DF91CF911F910F91FF900C947F050E\r\n\
:101D9000DF91CF911F910F91FF900895E091550130\r\n\
:101DA000F0915601309721F00480F581E02D0994DF\r\n\
:101DB000089520915301309154018217930771F0D7\r\n\
:101DC0009093540180935301E0915501F091560195\r\n\
:101DD000309721F00680F781E02D09940895209135\r\n\
:101DE0005101309152018217930771F09093520183\r\n\
:101DF00080935101E0915501F0915601309721F007\r\n\
:101E00000084F185E02D0994089508950C94050F40\r\n\
:101E10000E94301C0E9447060C94F61CCF93C82FDA\r\n\
:101E20008091AB0182FF1EC080FF04C087EC92E06E\r\n\
:101E30000E947F058091AB0180FF0CC01F92CF9361\r\n\
:101E400022EC32E03F932F930E9418060F900F90E0\r\n\
:101E50000F900F908091AB0180FF04C080EC92E066\r\n\
:101E60000E947F058C2FCF910C943F07CF92DF9279\r\n\
:101E7000EF92FF920F931F93CF93DF93CDB7DEB70F\r\n\
:101E80002B970FB6F894DEBF0FBECDBF0E946B0636\r\n\
:101E900038E5E32E31E0F32E00E010E0C02E802F75\r\n\
:101EA0000E94F206F701D1907F01D826B1F40F5FAE\r\n\
:101EB0001F4F0830110591F78FEF89838A831B82AA\r\n\
:101EC0000E94391C8160782F9D838C8349815A81BF\r\n\
:101ED0006B818D810E94D90F41C09091AB0191FF20\r\n\
:101EE00004C08B870E94F8068B8520E030E04D2DE2\r\n\
:101EF00050E0922FBA01022E02C0759567950A94A0\r\n\
:101F0000E2F760FF25C02E83CF82EE24E394F12C0C\r\n\
:101F100002C0EE0CFF1C9A95E2F790E08E219F2103\r\n\
:101F200021E0892B09F420E028870E94391C816078\r\n\
:101F3000782F9A8789874E815F8168858A850E947C\r\n\
:101F4000D90FF801E85AFE4F80818E25808306C0A4\r\n\
:101F50002F5F3F4F2830310561F6A9CF0E946320E3\r\n\
:101F6000109157010E947D0E1817A1F00E947D0E5E\r\n\
:101F7000809357012B960FB6F894DEBF0FBECDBFEE\r\n\
:101F8000DF91CF911F910F91FF90EF90DF90CF9055\r\n\
:101F90000C940E0F2B960FB6F894DEBF0FBECDBF7C\r\n\
:101FA000DF91CF911F910F91FF90EF90DF90CF9035\r\n\
:101FB0000895CF93DF93CDB7DEB72B970FB6F89484\r\n\
:101FC000DEBF0FBECDBF4F83588769877A878B8767\r\n\
:101FD000DE01119686E0FD0111928A95E9F785E010\r\n\
:101FE000FE01379601900D928A95E1F749815A8159\r\n\
:101FF0006B817C818D819E810E9418172B960FB674\r\n\
:10200000F894DEBF0FBECDBFDF91CF910895CF937F\r\n\
:10201000C82F882309F4C1C0823859F40E947D0E6C\r\n\
:1020200081FDBBC089E30E94BA190E94381A89E376\r\n\
:102030000CC0833879F40E947D0E80FDAEC083E52C\r\n\
:102040000E94BA190E94381A83E50E94DB19CF91C9\r\n\
:102050000C94381A843859F40E947D0E82FD9DC07C\r\n\
:1020600087E40E94BA190E94381A87E4EECF8CEFF9\r\n\
:102070008C0F813A48F48C2F0E94C12481118DC0AD\r\n\
:102080008C2F0E94BA19E3CF80E28C0F883048F47D\r\n\
:10209000C77081E001C0880FCA95EAF70E94FF1956\r\n\
:1020A000D6CF8BE58C0F833078F4C53A29F0C63A49\r\n\
:1020B00031F482E890E005C081E890E002C083E856\r\n\
:1020C00090E0CF910C94D90E88E58C0F833108F005\r\n\
:1020D00064C0C83A39F1C93A41F1CA3A49F1CB3A38\r\n\
:1020E00051F1CC3A59F1CD3A61F1C03B69F1CE3AA8\r\n\
:1020F00071F1CF3A79F1C13B81F1C23B89F1C33B28\r\n\
:1021000091F1C43B99F1C53BA1F1C63BA9F1C73B95\r\n\
:10211000B1F1C83BB9F1C93BC1F1CA3BC9F58AE28B\r\n\
:1021200092E038C082EE90E035C089EE90E032C097\r\n\
:102130008AEE90E02FC085EB90E02CC086EB90E01B\r\n\
:1021400029C087EB90E026C08CEC90E023C08DEC9A\r\n\
:1021500090E020C083E891E01DC08AE891E01AC0B9\r\n\
:1021600082E991E017C084E991E014C081E292E035\r\n\
:1021700011C083E292E00EC084E292E00BC085E2DF\r\n\
:1021800092E008C086E292E005C087E292E002C0D9\r\n\
:1021900080E090E0CF910C94EF0ECF9108958823CA\r\n\
:1021A00009F44BC0823859F40E947D0E81FF45C06E\r\n\
:1021B00089E30E94BA190E94381A89E30CC0833857\r\n\
:1021C00071F40E947D0E80FF38C083E50E94BA1929\r\n\
:1021D0000E94381A83E50E94DB190C94381A84385F\r\n\
:1021E00059F40E947D0E82FF28C087E40E94BA192C\r\n\
:1021F0000E94381A87E4EFCF9CEF980F913A58F37A\r\n\
:1022000090E2980F983050F4877091E001C0990FD8\r\n\
:102210008A95EAF7892F0E94051ADFCF9BE5980F70\r\n\
:10222000933020F480E090E00C94D90E885A8331EA\r\n\
:1022300020F480E090E00C94EF0E0895882321F0C4\r\n\
:102240000E94FF190C94381A0895882321F00E94E7\r\n\
:10225000051A0C94381A0895CF92DF92EF92FF92EC\r\n\
:102260000F931F93CF93DF93CDB7DEB728970FB6A9\r\n\
:10227000F894DEBF0FBECDBF8C0185E0F801DE0112\r\n\
:10228000119601900D928A95E1F7F8014081318114\r\n\
:10229000F280258122952F7083819481892B31F0E2\r\n\
:1022A0003F3F31F481E04F3F19F403C081E001C0AA\r\n\
:1022B00080E080FDCFC249833A8389819A812F8350\r\n\
:1022C0000E9478199E8388870E9477190E944A1875\r\n\
:1022D0004E81E42FE295EF70F0E0E55BFF4F2F8138\r\n\
:1022E00068850C946E27842F807F142F1F7088239D\r\n\
:1022F00011F01295107FFF2059F0112309F45FC2ED\r\n\
:10230000812F68870E940F1A0E94381A688557C269\r\n\
:10231000862F0E94CF10112309F49CC2812F0E94A6\r\n\
:10232000151A28960FB6F894DEBF0FBECDBFDF9109\r\n\
:10233000CF911F910F91FF90EF90DF90CF900C9471\r\n\
:10234000381A842F807F942F9F70E92E803219F0E5\r\n\
:10235000E29480EFE822662319F0613001F129C090\r\n\
:10236000FF20A9F08E2D222349F1213039F528963E\r\n\
:102370000FB6F894DEBF0FBECDBFDF91CF911F9196\r\n\
:102380000F91FF90EF90DF90CF900C941F1A2223B3\r\n\
:1023900019F0213009F45EC20E94221A2CC0FF20DD\r\n\
:1023A000E9F0263008F056C20E94FC198E2129F06F\r\n\
:1023B00022C0FF20F1F0211115C08E2D28960FB6F6\r\n\
:1023C000F894DEBF0FBECDBFDF91CF911F910F916B\r\n\
:1023D000FF90EF90DF90CF900C941E11253008F005\r\n\
:1023E00039C209C0F801858180FFE9C18F708583FA\r\n\
:1023F000E4CF2111F8C18E2D66C1242F2695269594\r\n\
:10240000237030E02115310521F021303105C9F06C\r\n\
:1024100021C2FF2021F0862F942F937002C080E00C\r\n\
:1024200090E028960FB6F894DEBF0FBECDBFDF91C7\r\n\
:10243000CF911F910F91FF90EF90DF90CF900C9470\r\n\
:10244000D90EFF2021F0862F942F937002C080E0D8\r\n\
:1024500090E028960FB6F894DEBF0FBECDBFDF9197\r\n\
:10246000CF911F910F91FF90EF90DF90CF900C9440\r\n\
:10247000EF0E862FFF2019F00E94E91E02C00E9475\r\n\
:10248000511F28960FB6F894DEBF0FBECDBFDF9167\r\n\
:10249000CF911F910F91FF90EF90DF90CF900C9410\r\n\
:1024A000D61F842F837009F076C0F110D3C1262F78\r\n\
:1024B000229526952770220F220F862F8F70C82E07\r\n\
:1024C000D12CE12CF12C022E04C0CC0CDD1CEE1C16\r\n\
:1024D000FF1C0A94D2F764FF10C06FE070E080E048\r\n\
:1024E00090E004C0660F771F881F991F2A95D2F7C6\r\n\
:1024F000609570958095909503C060E070E0CB0189\r\n\
:10250000242F269526952370422F50E04230510506\r\n\
:10251000D1F04330510559F16C297D298E299F292D\r\n\
:102520004130510541F128960FB6F894DEBF0FBE39\r\n\
:10253000CDBFDF91CF911F910F91FF90EF90DF9072\r\n\
:10254000CF900C946F186C297D298E299F2928968D\r\n\
:102550000FB6F894DEBF0FBECDBFDF91CF911F91B4\r\n\
:102560000F91FF90EF90DF90CF900C9489180E940C\r\n\
:102570006F18C701B60128960FB6F894DEBF0FBEDC\r\n\
:10258000CDBFDF91CF911F910F91FF90EF90DF9022\r\n\
:10259000CF900C945518FF2019F0842F817001C042\r\n\
:1025A0008695882309F456C1262F229526952770F3\r\n\
:1025B000220F220F862F8F70C82ED12CE12CF12CE8\r\n\
:1025C000022E04C0CC0CDD1CEE1CFF1C0A94D2F7BA\r\n\
:1025D00064FF10C06FE070E080E090E004C0660F20\r\n\
:1025E000771F881F991F2A95D2F76095709580955F\r\n\
:1025F000909503C060E070E0CB01242F26952695CE\r\n\
:102600002370422F50E042305105D1F04330510544\r\n\
:1026100059F16C297D298E299F294130510541F1BD\r\n\
:1026200028960FB6F894DEBF0FBECDBFDF91CF91D5\r\n\
:102630001F910F91FF90EF90DF90CF900C94431972\r\n\
:102640006C297D298E299F2928960FB6F894DEBF24\r\n\
:102650000FBECDBFDF91CF911F910F91FF90EF90F3\r\n\
:10266000DF90CF900C945D190E944319C701B60109\r\n\
:1026700028960FB6F894DEBF0FBECDBFDF91CF9185\r\n\
:102680001F910F91FF90EF90DF90CF900C9429193C\r\n\
:10269000603F49F118F4603E48F48CC0623F09F491\r\n\
:1026A00051C0E0F1633F09F461C084C0162F1F7070\r\n\
:1026B000842F8F71FF2021F00E94C218812F7ECEBF\r\n\
:1026C0000E94E318812F28960FB6F894DEBF0FBE44\r\n\
:1026D000CDBFDF91CF911F910F91FF90EF90DF90D1\r\n\
:1026E000CF900C942511FF20A9F0253008F0B2C03E\r\n\
:1026F000842F8F7128960FB6F894DEBF0FBECDBF22\r\n\
:10270000DF91CF911F910F91FF90EF90DF90CF90CD\r\n\
:102710000C940819263008F09DC0EACFFF20A1F0E4\r\n\
:10272000842F8F7128960FB6F894DEBF0FBECDBFF1\r\n\
:10273000DF91CF911F910F91FF90EF90DF90CF909D\r\n\
:102740000C94C218FF2061F3842F8F7128960FB666\r\n\
:10275000F894DEBF0FBECDBFDF91CF911F910F91D7\r\n\
:10276000FF90EF90DF90CF900C94E318FF2091F052\r\n\
:10277000842F8F7128960FB6F894DEBF0FBECDBFA1\r\n\
:10278000DF91CF911F910F91FF90EF90DF90CF904D\r\n\
:102790000C94AD1828960FB6F894DEBF0FBECDBFCF\r\n\
:1027A000DF91CF911F910F91FF90EF90DF90CF902D\r\n\
:1027B0000C94A318FF20A1F0222309F4B1CF862F97\r\n\
:1027C00028960FB6F894DEBF0FBECDBFDF91CF9134\r\n\
:1027D0001F910F91FF90EF90DF90CF900C94071016\r\n\
:1027E000222309F4B1CF862F28960FB6F894DEBFC6\r\n\
:1027F0000FBECDBFDF91CF911F910F91FF90EF9052\r\n\
:10280000DF90CF900C94CF104F70C8010E94961BA0\r\n\
:1028100028960FB6F894DEBF0FBECDBFDF91CF91E3\r\n\
:102820001F910F91FF90EF90DF90CF900C94CA17FB\r\n\
:102830004F70C80128960FB6F894DEBF0FBECDBF0B\r\n\
:10284000DF91CF911F910F91FF90EF90DF90CF908C\r\n\
:102850000C94991B28960FB6F894DEBF0FBECDBF1F\r\n\
:10286000DF91CF911F910F91FF90EF90DF90CF906C\r\n\
:1028700008950E941C1A0E94EE190E94381A0E94A4\r\n\
:1028800006210E94D61F80E090E00E94D90E80E0D1\r\n\
:1028900090E00C94EF0E0E940C1A0C9439140E94D4\r\n\
:1028A0007819292F22952F7030E02C3031054CF407\r\n\
:1028B0002A3031056CF4225031092230310590F470\r\n\
:1028C00007C02C30310551F02F30310539F00AC0E6\r\n\
:1028D000803E10F0803F31F481E0089593FB88271B\r\n\
:1028E00080F9089580E00895CF93DF9300D000D061\r\n\
:1028F0001F92CDB7DEB70F900F900F900F900F90F3\r\n\
:10290000DF91CF910895CF93DF9300D000D000D016\r\n\
:10291000CDB7DEB726960FB6F894DEBF0FBECDBF9B\r\n\
:10292000DF91CF910895CF93DF93C09160018091A3\r\n\
:102930006101C817A1F0D0E0CE0166E070E00E940E\r\n\
:102940003D27FC01EE59FE4F408151816281738128\r\n\
:10295000848195810E9483142196C770E8CFDF910E\r\n\
:10296000CF9108954091920150919301609194010B\r\n\
:102970007091950180919601909197010C94831428\r\n\
:102980001F93CF93DF938091970182958F7009F009\r\n\
:1029900060C080919401882309F45BC0A09160011C\r\n\
:1029A000D091610140919201C091930120919501D4\r\n\
:1029B0003091960181E04F3F09F080E0182FAD176C\r\n\
:1029C00009F447C02115310521F0CF3F21F4812FB3\r\n\
:1029D00003C081E001C080E0B0E080FD37C0CD01E0\r\n\
:1029E00066E070E00E943D27FC01EE59FE4F8181B8\r\n\
:1029F000C8132CC08081481329C08281811126C050\r\n\
:102A0000838194818217930708F40197821B930BAB\r\n\
:102A1000883C9105D8F4809197018F7080618093F4\r\n\
:102A20009701CD0166E070E00E943D27FC01E95965\r\n\
:102A3000FE4F80818F708061808382E991E00E94E7\r\n\
:102A40002C11DF91CF911F910C9493141196A770C4\r\n\
:102A5000B6CFDF91CF911F910895BF92CF92DF92B1\r\n\
:102A6000EF92FF920F931F93CF93DF93CDB7DEB713\r\n\
:102A700061970FB6F894DEBF0FBECDBF8C0185E025\r\n\
:102A8000F801DE011D9601900D928A95E1F7D801BB\r\n\
:102A90004C911196AC91F801C280E380F480509182\r\n\
:102AA0009201609193012091950130919601211539\r\n\
:102AB000310531F06F3F31F481E05F3F19F403C01D\r\n\
:102AC00081E001C080E0F82FF170BF2E80FD6DC164\r\n\
:102AD000D0909401DD2009F4F4C070919701E216C2\r\n\
:102AE000F30638F0C701821B930B883C910548F030\r\n\
:102AF00099C0209530952E0D3F1D283C310508F0DA\r\n\
:102B000091C0872F807F09F054C06A1315C05413F9\r\n\
:102B100013C0DC2CC11010C07F70706170939701DE\r\n\
:102B20000E94B21482E991E00E942C1180919701D9\r\n\
:102B3000D80115968C936BC1EF2831F0AF3F31F47B\r\n\
:102B400081E04F3F19F403C081E001C080E080FDC7\r\n\
:102B500003C081E08C2501C080E0B82FB170FB2E4E\r\n\
:102B600080FF1DC020916001B09161012B1709F415\r\n\
:102B700029C130E0C90166E070E00E943D27FC01F8\r\n\
:102B8000EE59FE4F8181A81306C08081481303C00F\r\n\
:102B90008281C81204C02F5F3F4F2770E7CFDC2C23\r\n\
:102BA000CC2009F434C18091970181608093970112\r\n\
:102BB00051C06A1308C0541306C0C11004C0D80124\r\n\
:102BC00015967C93ABC04D87AE878D859E850E9400\r\n\
:102BD0004F14882319F1DC2CCC2001F120919701AE\r\n\
:102BE000822F82958F7090E002970CF45FC08091E5\r\n\
:102BF00092019091930198878F831986FB86EA86CC\r\n\
:102C00002C87CE01079650C06A1731F14D87AE87E9\r\n\
:102C10008D859E850E944F1481112FC0C8010E948E\r\n\
:102C20002C11A5C0872F807F79F77E2DF98AE88A3D\r\n\
:102C30005A2F6C2D89890E94741482E991E00E94B8\r\n\
:102C40002C11E2E9F1E086E0DF011D928A95E9F7B7\r\n\
:102C50000E94B214D12CDBC05413D8CFC110D6CFF0\r\n\
:102C6000F8017583C8010E942C11E2E9F1E086E0C9\r\n\
:102C7000DF011D928A95E9F7CAC0DC2CCC2071F2E5\r\n\
:102C800020919701822F82958F7090E0029774F0C7\r\n\
:102C900080919201909193019A8389831B82FD8296\r\n\
:102CA000EC822E83CE0101960E942C1186E0F80161\r\n\
:102CB000A2E9B1E001900D928A95E1F70E94C0145B\r\n\
:102CC00071C0E216F30628F0F701E21BF30B9F0137\r\n\
:102CD00004C0209530952E0D3F1D283C310508F08D\r\n\
:102CE00052C0DC2CCC2009F499CF6A132CC05413A9\r\n\
:102CF0002AC08091970180FD1DC0982F92959F70EA\r\n\
:102D0000C9F0D80115968C9315979F3039F09F5FC5\r\n\
:102D10009295907F8F70892B15968C93C8010E9495\r\n\
:102D20002C1186E0F801A2E9B1E001900D928A959C\r\n\
:102D3000E1F738C086E0F801A2E9B1E001900D9218\r\n\
:102D40008A95E1F764C04D87AE878D859E850E9488\r\n\
:102D50004F14882379F086E0F801A2E9B1E00190F0\r\n\
:102D60000D928A95E1F70E94C0140E94B214DD24EE\r\n\
:102D7000D3944DC080919701816080939701C801E1\r\n\
:102D80000E942C1144C07E2DF98AE88A5A2F6C2D9E\r\n\
:102D900089890E947414E2E9F1E086E0DF011D9266\r\n\
:102DA0008A95E9F70E94B21432C0CC2009F436CFDC\r\n\
:102DB0004D87AE878D859E850E944F14882309F428\r\n\
:102DC0002DCFC9CF4D87AE878D859E850E947819FE\r\n\
:102DD000292F22952F7030E0223031052CF49F707E\r\n\
:102DE00041F0811106C00CC0243031052CF49F70D5\r\n\
:102DF00049F4805E883020F0C8010E942C11BF2C5D\r\n\
:102E0000DB2C05C0F8019581907F99F7F9CF8D2DC6\r\n\
:102E100061960FB6F894DEBF0FBECDBFDF91CF91A4\r\n\
:102E20001F910F91FF90EF90DF90CF90BF9008958A\r\n\
:102E3000CF93DF93CDB7DEB72C970FB6F894DEBFF4\r\n\
:102E40000FBECDBF4F83588769877A878B879C8752\r\n\
:102E5000CE0107960E942D158823C1F02F81388559\r\n\
:102E60008A859B85892B31F03F3F11F080E003C0BC\r\n\
:102E70002F3FE1F781E081116FC04F81588569854F\r\n\
:102E80007A858B859C850E94831466C086E0FE014E\r\n\
:102E90003796DE01119601900D928A95E1F7FF8138\r\n\
:102EA000E8854A855B854115510531F0EF3F31F4E6\r\n\
:102EB00081E0FF3F19F403C081E001C080E080FDA4\r\n\
:102EC0004BC08091610190E09C012F5F3F4F2770C4\r\n\
:102ED00033276091600170E02617370709F443C07B\r\n\
:102EE000F983EA835D834C8366E070E00E943D27AE\r\n\
:102EF000DC01AE59BE4F86E0FE01319601900D9285\r\n\
:102F00008A95E1F7209361010E94931425C090E017\r\n\
:102F100066E070E00E943D278E599E4F0E942D155D\r\n\
:102F2000882379F18091600190E066E070E00E9472\r\n\
:102F30003D27FC01EE59FE4F408151816281738132\r\n\
:102F4000848195810E9483148091600190E00196B4\r\n\
:102F50008770992780936001809160019091610151\r\n\
:102F60008913D5CF0EC00E944B14109261011092AC\r\n\
:102F70006001E2E9F1E086E0DF011D928A95E9F760\r\n\
:102F8000EBCF2C960FB6F894DEBF0FBECDBFDF910E\r\n\
:102F9000CF910895EF92FF920F931F93CF93DF93FA\r\n\
:102FA000FC01009709F46FC0F12CEE24E394EF01CB\r\n\
:102FB00021968491843740F4843008F055C08130E4\r\n\
:102FC00081F0823021F15FC0853709F447C0C0F13C\r\n\
:102FD0009CE7980F903708F056C08F770E94CF106B\r\n\
:102FE00045C08F010E5F1F4FFE01849190E2980F44\r\n\
:102FF000983050F48770FE2D01C0FF0F8A95EAF7D4\r\n\
:103000008F2F0E940F1A15C00E94071014C08F0145\r\n\
:103010000E5F1F4FFE01849190E2980F983068F484\r\n\
:103020008770FE2D01C0FF0F8A95EAF78F2F0E944F\r\n\
:10303000151A0E94381AE80119C00E94CF10FBCF60\r\n\
:10304000CF010296FE01C491CC2361F0EFE9FFE0CD\r\n\
:103050003197F1F700C00000C150F6CFCF010296C2\r\n\
:10306000FE01F490EC0102C00E9407108F2D88230E\r\n\
:1030700041F0EFE9FFE03197F1F700C00000815027\r\n\
:10308000F6CFFE0194CFDF91CF911F910F91FF906A\r\n\
:10309000EF900895089560939C0170939D01809333\r\n\
:1030A0009E0190939F010C9439140F931F930091EC\r\n\
:1030B0009C0110919D0120919E0130919F01062B52\r\n\
:1030C000172B282B392B00939C0110939D012093E3\r\n\
:1030D0009E0130939F011F910F910C9439140F930F\r\n\
:1030E0001F9300919C0110919D0120919E013091B0\r\n\
:1030F0009F01062317232823392300939C01109353\r\n\
:103100009D0120939E0130939F011F910F910C947C\r\n\
:1031100039140F931F9300919C0110919D012091F0\r\n\
:103120009E0130919F0106271727282739270093F2\r\n\
:103130009C0110939D0120939E0130939F011F914C\r\n\
:103140000F910C94391410929801109299011092D9\r\n\
:103150009A0110929B010C94391441E050E060E018\r\n\
:1031600070E004C0440F551F661F771F8A95D2F781\r\n\
:10317000409398015093990160939A0170939B0139\r\n\
:103180000C94391441E050E060E070E004C0440F5A\r\n\
:10319000551F661F771F8A95D2F7809198019091ED\r\n\
:1031A0009901A0919A01B0919B01842B952BA62B9C\r\n\
:1031B000B72B8093980190939901A0939A01B093B3\r\n\
:1031C0009B010C94391441E050E060E070E004C0D1\r\n\
:1031D000440F551F661F771F8A95D2F7409550956B\r\n\
:1031E000609570958091980190919901A0919A01B4\r\n\
:1031F000B0919B0184239523A623B7238093980144\r\n\
:1032000090939901A0939A01B0939B010C94391467\r\n\
:1032100041E050E060E070E004C0440F551F661FBD\r\n\
:10322000771F8A95D2F78091980190919901A0918A\r\n\
:103230009A01B0919B0184279527A627B7278093F1\r\n\
:10324000980190939901A0939A01B0939B010C94DB\r\n\
:1032500039140F931F9300919801109199012091B7\r\n\
:103260009A0130919B01062B172B282B392B0093A9\r\n\
:1032700098011093990120939A0130939B011F911B\r\n\
:103280000F910C9439140F931F9300919801109192\r\n\
:10329000990120919A0130919B010623172328233D\r\n\
:1032A0003923009398011093990120939A01309348\r\n\
:1032B0009B011F910F910C9439140F931F93009150\r\n\
:1032C00098011091990120919A0130919B01062754\r\n\
:1032D00017272827392700939801109399012093E5\r\n\
:1032E0009A0130939B011F910F910C94391408950A\r\n\
:1032F000CF92DF92EF92FF920F931F93CF93DF93C2\r\n\
:10330000EC01C0909C01D0909D01E0909E01F09056\r\n\
:103310009F018091980190919901A0919A01B0919B\r\n\
:103320009B01C82AD92AEA2AFB2A0FE110E0B7013B\r\n\
:10333000A601002E04C076956795579547950A9487\r\n\
:10334000D2F740FF07C0BE01802F0E94231B8130AF\r\n\
:10335000910539F40150110950F7BE0180E00E9437\r\n\
:10336000231BDF91CF911F910F91FF90EF90DF9082\r\n\
:10337000CF90089540910C0150910D0120E030E074\r\n\
:103380009FEFFA01E20FF31F6281681799F09F3FE8\r\n\
:1033900019F4611101C0922F2F5F3F4F2630310584\r\n\
:1033A00081F79F3F39F0FA01E90FF11D97FDFA957A\r\n\
:1033B00082830895089540910C0150910D0120E001\r\n\
:1033C00030E0FA01E20FF31F9281981301C01282DC\r\n\
:1033D0002F5F3F4F26303105A1F7089581E090E03F\r\n\
:1033E000E0910C01F0910D01E80FF91F1082019698\r\n\
:1033F00088309105A9F708958091AA0108959091C8\r\n\
:10340000AA01982B9093AA01089580959091AA0102\r\n\
:1034100098239093AA0108951092AA01089590917B\r\n\
:10342000A901982B9093A901089580959091A901E5\r\n\
:1034300098239093A90108951092A901089580936B\r\n\
:10344000A00108951092A001089540910C0150919F\r\n\
:103450000D0120E030E080E0FA01E20FF31F9181DE\r\n\
:1034600091118F5F2F5F3F4F27303105A9F70895E6\r\n\
:10347000E0910C01F0910D018091AA018083E0910F\r\n\
:103480000C01F0910D0180819091A901892B80831D\r\n\
:103490009091A001992361F0E0910C01F0910D0150\r\n\
:1034A0008081892B80830E94251A81111092A001AE\r\n\
:1034B00080910C0190910D010C94890ECF93DF93B4\r\n\
:1034C0008D3B60F4883A90F5853A38F5843010F5F4\r\n\
:1034D000813009F06DC0C1E0D0E0B1C0883E98F401\r\n\
:1034E000803EC0F48F3B09F063C00E944B142FEF65\r\n\
:1034F00080E792E0215080409040E1F700C000005A\r\n\
:103500000E94931C9CC0803F08F452C0C82FD0E09A\r\n\
:10351000D06595C0C82FD0E092C0853A09F44BC061\r\n\
:10352000863A09F04BC0C2E8D0E489C0883A09F471\r\n\
:1035300048C0893A09F448C08A3A09F448C08B3A2D\r\n\
:1035400009F448C08C3A09F448C08B3B09F448C0E0\r\n\
:103550008C3B09F448C08D3A09F448C0803B09F41B\r\n\
:1035600048C08E3A09F448C08F3A09F448C0813BFC\r\n\
:1035700009F448C0823B09F448C0833B09F448C0C1\r\n\
:10358000843B09F448C0853B09F448C0863B09F4F4\r\n\
:1035900048C0873B09F448C0883B09F448C0893BD0\r\n\
:1035A00009F448C08A3B09F048C0CAE2D6E447C0E3\r\n\
:1035B000C0E0D0E044C0C1E8D0E441C0C3E8D0E4FA\r\n\
:1035C0003EC0C2EED4E43BC0C9EED4E438C0CAEE7B\r\n\
:1035D000D4E435C0C5EBD4E432C0C6EBD4E42FC08C\r\n\
:1035E000C3EBD4E42CC0C4EBD4E429C0C7EBD4E4CF\r\n\
:1035F00026C0CCECD4E423C0CDECD4E420C0C3E896\r\n\
:10360000D5E41DC0CAE8D5E41AC0C2E9D5E417C0A4\r\n\
:10361000C4E9D5E414C0C1E2D6E411C0C3E2D6E4E3\r\n\
:103620000EC0C4E2D6E40BC0C5E2D6E408C0C6E2D0\r\n\
:10363000D6E405C0C7E2D6E402C0C0E0D4E4CE01BF\r\n\
:10364000DF91CF9108950E942106803EA8F4803C2E\r\n\
:1036500000F5813309F45CC038F4893209F452C0B2\r\n\
:103660008A3209F45BC05FC08933B1F08238A1F0BF\r\n\
:10367000853309F441C057C0833E41F128F4803EB0\r\n\
:1036800099F0823EB9F04FC0863E31F1873E71F12C\r\n\
:103690004AC00E94350608959091BC0190FD02C079\r\n\
:1036A00091FF41C080EE3FC08091BC0180FFFACF06\r\n\
:1036B00089E339C08091BC0182FF0CC08091BC01BC\r\n\
:1036C00084FF02C080E02FC083EE2DC08091BC013A\r\n\
:1036D00082FFF4CF82EE27C08091BC0183FF0AC035\r\n\
:1036E0008091BC0184FDEECF87EE1DC08091BC01AE\r\n\
:1036F00083FFF6CF86EE17C08091BC0185FF06C020\r\n\
:1037000089E211C08091BC0185FFFACF85E30BC02F\r\n\
:103710008091BC0186FF06C08AE205C08091BC0191\r\n\
:1037200086FFFACF81E30E945E1A089580E090E060\r\n\
:1037300008950895909333018093320108958295FE\r\n\
:10374000282F2C7C26952695982F9373990F990FE7\r\n\
:10375000922B892F8A7A86959575990F892B0895D2\r\n\
:103760001F93CF93DF931F92CDB7DEB799830E944B\r\n\
:103770009F1B182F9981892F0E949F1B212F30E0BA\r\n\
:10378000322F2227A901482BCA010F90DF91CF9138\r\n\
:103790001F9108958091C101843009F11092AC010C\r\n\
:1037A00020E488E190E00FB6F894A895809360003B\r\n\
:1037B0000FBE2093600083B7817F846083BF83B78F\r\n\
:1037C000816083BF7894889583B78E7F83BF88E1BB\r\n\
:1037D0000FB6F89480936000109260000FBE0895B9\r\n\
:1037E00008950895CF930E94F01B0E946B060E94DB\r\n\
:1037F000F11BC0E08C2F0E94F206811105C0CF5F43\r\n\
:10380000C830C1F780E001C081E0CF9108951F92D8\r\n\
:103810000F920FB60F9211248F939F93AF93BF9384\r\n\
:103820008091AC01811113C08091AD019091AE01E6\r\n\
:10383000A091AF01B091B0014196A11DB11D80933F\r\n\
:10384000AD019093AE01A093AF01B093B001BF91D1\r\n\
:10385000AF919F918F910F900FBE0F901F90189571\r\n\
:1038600082E084BD93E095BD9AEF97BD80936E0092\r\n\
:1038700008952FB7F8948091AD019091AE01A09179\r\n\
:10388000AF01B091B0012FBF0895CF92DF92EF92B8\r\n\
:10389000FF920F931F932FB7F8944091AD01509171\r\n\
:1038A000AE016091AF017091B0012FBF6A017B0141\r\n\
:1038B000EE24FF248C0120E030E0C016D106E206A1\r\n\
:1038C000F30610F441505109481B590BCA011F91CE\r\n\
:1038D0000F91FF90EF90DF90CF9008951F920F927D\r\n\
:1038E0000FB60F9211248F939F93AF93BF93809144\r\n\
:1038F000AD019091AE01A091AF01B091B0010196E0\r\n\
:10390000A11DB11D8093AD019093AE01A093AF01B5\r\n\
:10391000B093B001BF91AF919F918F910F900FBE67\r\n\
:103920000F901F9018950E94DD0BF8942FEF87EAF7\r\n\
:1039300091E6215080409040E1F700C0000087E010\r\n\
:1039400090EBDC018093CA019093CB01A093CC0152\r\n\
:10395000B093CD012CE088E190E00FB6F894A895E3\r\n\
:10396000809360000FBE20936000FFCFEF92FF9224\r\n\
:103970000F931F93CF93DF93E82EF12C8F2D0E948E\r\n\
:10398000F206C0E0D0E0082F10E098010C2E02C033\r\n\
:10399000359527950A94E2F720FD05C02196C83099\r\n\
:1039A000D10599F709C06C2F7F2D80E00E94210678\r\n\
:1039B000E812F4CF81E005C0F39488E0F812DECF7E\r\n\
:1039C00080E0DF91CF911F910F91FF90EF900895CC\r\n\
:1039D000CF93C82F8CE20E94B61C882321F08C2F35\r\n\
:1039E000CF910C94B61C80E0CF910895CF930E94A4\r\n\
:1039F0003C1E811102C00E94221E81EE92E00E94B4\r\n\
:103A00007F05C5E6C15049F00E946B068FE39CE933\r\n\
:103A10000197F1F700C00000F5CF8AED92E00E9417\r\n\
:103A20007F0589E20E94E81C81110AC18AE20E9496\r\n\
:103A3000E81C81110E94221E85E00E94E81C811171\r\n\
:103A40000E94931C0E94471E8093AB0187E00E9456\r\n\
:103A5000E81C882399F18BE10E94E81C882351F02F\r\n\
:103A60009091AB0191FB882780F921E0822780FBB0\r\n\
:103A700091F922C08EE00E94E81C882351F09091B9\r\n\
:103A8000AB0192FB882780F921E0822780FB92F925\r\n\
:103A900013C080E10E94E81C9091AB01882341F0A3\r\n\
:103AA00093FB882780F921E0822780FB93F904C0EB\r\n\
:103AB000892F809580FB90F99093AB018091AB01A9\r\n\
:103AC0000E944B1E0E94591E8093BC0180EE0E94F2\r\n\
:103AD000E81C882341F08091BC01982F909590FBC1\r\n\
:103AE00080F98093BC0189E30E94E81C882359F087\r\n\
:103AF0009091BC0191FB882780F921E0822780FB0F\r\n\
:103B000091F99093BC0182EE0E94E81C882359F041\r\n\
:103B10009091BC0192FB882780F921E0822780FBED\r\n\
:103B200092F99093BC0186EE0E94E81C882359F01C\r\n\
:103B30009091BC0193FB882780F921E0822780FBCC\r\n\
:103B400093F99093BC0183EE0E94E81C882359F0FE\r\n\
:103B50009091BC0194FB882780F921E0822780FBAB\r\n\
:103B600094F99093BC0185E30E94E81C882359F0E6\r\n\
:103B70009091BC0195FB882780F921E0822780FB8A\r\n\
:103B800095F99093BC0181E30E94E81C882359F0C9\r\n\
:103B90009091BC0196FB882780F921E0822780FB69\r\n\
:103BA00096F99093BC0181E10E94E81C882359F0AA\r\n\
:103BB0009091BC0197FB882780F921E0822780FB48\r\n\
:103BC00097F99093BC018091BC010E945D1E87E231\r\n\
:103BD0000E94E81CC82F8EE10E94E81C8111C2607F\r\n\
:103BE0008FE10E94E81C8111C46080E20E94E81C01\r\n\
:103BF0008111C86081E20E94E81C8111C06182E2EB\r\n\
:103C00000E94E81C8111C06283E20E94E81C8111BD\r\n\
:103C1000C06484E20E94E81C882311F0C06802C0DE\r\n\
:103C2000CC2329F08C2F0E94541E6C2F03C00E94BD\r\n\
:103C3000501E682F70E080E090E0CF910C944B18FC\r\n\
:103C4000CF9108956DEE7EEF80E090E00E94A42772\r\n\
:103C500060E082E090E00E94962760E083E090E0E0\r\n\
:103C60000E94962760E084E090E00E94962760E042\r\n\
:103C700085E090E00C94962780E090E00E949027E9\r\n\
:103C800021E08D3E9E4F09F020E0822F089582E0D2\r\n\
:103C900090E00C948827682F82E090E00C9496279F\r\n\
:103CA00083E090E00C948827682F83E090E00C94E8\r\n\
:103CB000962784E090E00C948827682F84E090E0B9\r\n\
:103CC0000C9496278091B30180FF0CC08091110164\r\n\
:103CD00090E065E070E00E943D2795958795959569\r\n\
:103CE00087952EC081FF0AC08091110190E065E0A8\r\n\
:103CF00070E00E943D279595879522C082FF08C0FD\r\n\
:103D00008091110190E065E070E00E943D2718C0AD\r\n\
:103D10002091B4012223D1F030911001231780F7B4\r\n\
:103D20008091110190E065E070E00E943D27622FD4\r\n\
:103D300070E00E943D27632F70E00E945A27CB015C\r\n\
:103D40008038910530F4009731F0089585E090E0D7\r\n\
:103D500008958FE7089581E008958091B30180FF71\r\n\
:103D600008C060910F0170E075956795759567952E\r\n\
:103D700024C081FF06C060910F0170E075956795C2\r\n\
:103D80001CC082FF04C060910F0170E013C09091CD\r\n\
:103D9000B4019923D9F020910E019217A0F78091D8\r\n\
:103DA0000F01692F70E090E00E943D27622F70E0C4\r\n\
:103DB0000E945A276038710528F46115710521F0B9\r\n\
:103DC000862F08958FE7089581E0089561E070E0FF\r\n\
:103DD000F4CF803F21F40E94621E819504C0813F90\r\n\
:103DE00029F40E94621E8093B7010895823F21F456\r\n\
:103DF0000E94621E819504C0833F29F40E94621EC6\r\n\
:103E00008093B6010895893F19F40E94AD1E05C044\r\n\
:103E10008A3F31F40E94AD1E81958093B8010895C8\r\n\
:103E20008B3F21F40E94AD1E819504C08C3F29F484\r\n\
:103E30000E94AD1E8093B9010895843F21F48091C2\r\n\
:103E4000B501816017C0853F21F48091B501826082\r\n\
:103E500011C0863F21F48091B50184600BC0873F7B\r\n\
:103E600021F48091B501886005C0883F31F48091CC\r\n\
:103E7000B50180618093B50108958D3F21F4809153\r\n\
:103E8000B30181600BC08E3F21F48091B301826049\r\n\
:103E900005C08F3F29F48091B30184608093B30102\r\n\
:103EA0000895803F39F48091B70187FF6CC010926C\r\n\
:103EB000B70169C0813F29F48091B7011816BCF39E\r\n\
:103EC00062C09091B601823F29F497FF5CC01092C6\r\n\
:103ED000B60159C0833F19F41916CCF354C0893F79\r\n\
:103EE00041F48091B80118160CF04DC01092B80141\r\n\
:103EF0004AC08A3F29F48091B80187FF44C0F6CFB9\r\n\
:103F00008B3F39F48091B90187FF3DC01092B90110\r\n\
:103F10003AC08C3F29F48091B9011816BCF333C024\r\n\
:103F2000843F21F48091B5018E7F17C0853F21F435\r\n\
:103F30008091B5018D7F11C0863F21F48091B5013C\r\n\
:103F40008B7F0BC0873F21F48091B501877F05C02F\r\n\
:103F5000883F31F48091B5018F7E8093B50113C005\r\n\
:103F60008D3F21F48091B3018E7F0BC08E3F21F4F1\r\n\
:103F70008091B3018D7F05C08F3F29F48091B301FB\r\n\
:103F80008B7F8093B3018091B60181110EC0809127\r\n\
:103F9000B70181110AC08091B801811106C08091DA\r\n\
:103FA000B901811102C01092B40108958091AB0152\r\n\
:103FB00083FF7EC08DE193E00E947F058091B50173\r\n\
:103FC0001F928F9388E193E09F938F930E9418062E\r\n\
:103FD00086E193E00E947F052091B601822F992708\r\n\
:103FE00087FD90959F932F9383E193E09F938F9309\r\n\
:103FF0000E94180681E193E00E947F052091B7019D\r\n\
:10400000822F992787FD90959F932F938EE093E0C1\r\n\
:104010009F938F930E9418068CE093E00E947F0587\r\n\
:104020002091B801822F992787FD90959F932F9318\r\n\
:1040300089E093E09F938F930E94180687E093E0B6\r\n\
:104040000E947F052091B901822F992787FD9095C5\r\n\
:104050009F932F9384E093E09F938F930E94180681\r\n\
:1040600081E093E00E947F058091B4011F928F93BD\r\n\
:104070008EEF92E09F938F930E9418068CEF92E050\r\n\
:104080000E947F058091B3011F928F9389EF92E088\r\n\
:104090009F938F930E94180686EF92E00E947F05FF\r\n\
:1040A0008DB79EB74C960FB6F8949EBF0FBE8DBFCE\r\n\
:1040B00085EB91E00E94CE0E0E94391C9093B201D4\r\n\
:1040C0008093B10108951F93CF93DF938091B10145\r\n\
:1040D0009091B2010E94451C9C014091B40144237F\r\n\
:1040E00021F08091120190E007C08091130190E0CF\r\n\
:1040F0006AE070E00E943D272817390708F482C063\r\n\
:104100008091B6011091B701D091B801C091B90169\r\n\
:10411000811107C0111105C0D11103C0CC2309F4CE\r\n\
:1041200071C04F3F19F04F5F4093B401181624F44B\r\n\
:104130000E94621E8093B6018091B60187FF05C080\r\n\
:104140000E94621E81958093B601111624F40E948C\r\n\
:10415000621E8093B7018091B70187FF05C00E945E\r\n\
:10416000621E81958093B7016091B601662339F193\r\n\
:104170001091B701112319F1772767FD7095872FEB\r\n\
:10418000972F0E94462623E333E343E35FE30E9435\r\n\
:10419000AA260E9413266093B601612F772767FD38\r\n\
:1041A0007095872F972F0E94462623E333E343E33E\r\n\
:1041B0005FE30E94AA260E9413266093B7011D1692\r\n\
:1041C00024F40E94AD1E8093B8018091B80187FF4E\r\n\
:1041D00005C00E94AD1E81958093B8011C1624F481\r\n\
:1041E0000E94AD1E8093B9018091B90187FF05C07F\r\n\
:1041F0000E94AD1E81958093B901DF91CF911F91EF\r\n\
:104200000C94D61FDF91CF911F910895E5EBF1E05B\r\n\
:1042100085E0DF011D928A95E9F71092B4011092B2\r\n\
:10422000B301089580E495E00E947F051F9281E02C\r\n\
:104230008F931F9285E08F9382EF94E09F938F93EB\r\n\
:104240000E9418060F900F900F900F900F900F90F4\r\n\
:1042500008958330E9F128F4813061F0823009F16A\r\n\
:104260000895853009F462C008F449C0863009F425\r\n\
:1042700074C0089520911301862F90E0820F911D44\r\n\
:104280008F3F910520F4620F6093130103C08FEFFD\r\n\
:1042900080931301809113011F928F938BE294E01E\r\n\
:1042A00072C020911201862F90E0820F911D8F3FE6\r\n\
:1042B000910520F4620F6093120103C08FEF809389\r\n\
:1042C0001201809112011F928F9389E194E05BC0EB\r\n\
:1042D00020911101862F90E0820F911D8F3F910553\r\n\
:1042E00020F4620F6093110103C08FEF80931101DE\r\n\
:1042F000809111011F928F9386E094E044C0209139\r\n\
:104300001001862F90E0820F911D8F3F910520F4C0\r\n\
:10431000620F6093100103C08FEF809310018091B2\r\n\
:1043200010011F928F9381EF93E02DC020910F0118\r\n\
:10433000862F90E0820F911D8F3F910520F4620F30\r\n\
:1043400060930F0103C08FEF80930F0180910F01E5\r\n\
:104350001F928F9388ED93E016C020910E01862F57\r\n\
:1043600090E0820F911D8F3F910520F4620F6093C2\r\n\
:104370000E0103C08FEF80930E0180910E011F92FA\r\n\
:104380008F938DEB93E09F938F930E9418060F906D\r\n\
:104390000F900F900F900895833081F128F48130B1\r\n\
:1043A00059F08230D1F00895853009F449C0B8F150\r\n\
:1043B000863009F456C0089580911301681720F4DF\r\n\
:1043C000861B8093130102C0109213018091130188\r\n\
:1043D0001F928F938EEA93E054C080911201681768\r\n\
:1043E00020F4861B8093120102C01092120180916A\r\n\
:1043F00012011F928F938CE993E043C080911101C9\r\n\
:10440000681720F4861B8093110102C010921101DD\r\n\
:10441000809111011F928F9389E893E032C08091BF\r\n\
:104420001001681720F4861B8093100102C01092BF\r\n\
:104430001001809110011F928F9384E793E021C0B7\r\n\
:1044400080910F01681720F4861B80930F0102C032\r\n\
:1044500010920F0180910F011F928F938BE593E0D3\r\n\
:1044600010C080910E01681720F4861B80930E0106\r\n\
:1044700002C010920E0180910E011F928F9380E472\r\n\
:1044800093E09F938F930E9418060F900F900F90C8\r\n\
:104490000F900895CF93C82F1F928F9325E436E095\r\n\
:1044A0003F932F930E94180661E070E080E090E057\r\n\
:1044B00004C0660F771F881F991FCA95D2F70E9404\r\n\
:1044C0004B180F900F900F900F90CF910C944B14AE\r\n\
:1044D000CF938732B0F58E3108F043C28E3009F4A5\r\n\
:1044E000BDC100F5873009F48DC1A8F4863009F00C\r\n\
:1044F0003CC28091AB01817F8E7F8093AB018AE4C7\r\n\
:1045000096E00E947F058AE49AE00E947F0581E0A0\r\n\
:104510008093BB0175C1883009F43FC08B3009F42A\r\n\
:104520006BC123C2863109F4DDC120F4803109F466\r\n\
:10453000A8C11BC2893109F4BEC18B3109F47BC10A\r\n\
:1045400014C2883309F458C150F4893209F407C2FF\r\n\
:10455000853309F404C2873209F007C200C28334EC\r\n\
:1045600009F4FDC128F48A3308F4FFC18953FAC164\r\n\
:10457000883409F0FAC10E944B1489E39AE00E9442\r\n\
:104580007F059FEF23ED80E3915020408040E1F7CD\r\n\
:1045900000C000000E94931C33C18EE49AE00E9488\r\n\
:1045A0007F0581E498E00E947F050E94501E1F92C3\r\n\
:1045B0008F938EE398E09F938F930E9418068CE36D\r\n\
:1045C00098E00E947F050E94471EC82F89E298E06C\r\n\
:1045D0000E947F051F92CF9324E238E03F932F93F0\r\n\
:1045E0000E94180682E298E00E947F0588E198E028\r\n\
:1045F0000E947F058C2F81701F928F9325E138E0F8\r\n\
:104600003F932F930E94180683E198E00E947F0554\r\n\
:1046100089E098E00E947F05C1FB882780F91F92FE\r\n\
:104620008F9326E038E03F932F930E94180684E092\r\n\
:1046300098E00E947F0588EF97E00E947F05C2FB0B\r\n\
:10464000882780F91F928F9325EF37E03F932F93B0\r\n\
:104650000E94180683EF97E00E947F058AEE97E09C\r\n\
:104660000E947F05C3FBCC27C0F91F92CF9387EE32\r\n\
:1046700097E09F938F930E94180685EE97E00E9423\r\n\
:104680007F050E94591EC82F81ED97E00E947F058B\r\n\
:104690001F92CF932CEC37E03F932F930E94180684\r\n\
:1046A0008AEC97E00E947F0581EB97E00E947F05EE\r\n\
:1046B0008C2F81701F928F932EEA37E03F932F93B8\r\n\
:1046C0000E9418068DB79EB780960FB6F8949EBFCD\r\n\
:1046D0000FBE8DBF8CEA97E00E947F0585E997E0C9\r\n\
:1046E0000E947F05C1FB882780F91F928F9322E9E2\r\n\
:1046F00037E03F932F930E94180680E997E00E94CD\r\n\
:104700007F058EE797E00E947F05C2FB882780F92E\r\n\
:104710001F928F932BE737E03F932F930E94180649\r\n\
:1047200089E797E00E947F0587E697E00E947F0572\r\n\
:10473000C3FB882780F91F928F9324E637E03F93CD\r\n\
:104740002F930E94180682E697E00E947F0588E575\r\n\
:1047500097E00E947F05C4FB882780F91F928F9302\r\n\
:1047600025E537E03F932F930E94180683E597E0F5\r\n\
:104770000E947F0581E497E00E947F05C5FB8827A2\r\n\
:1047800080F91F928F932EE337E03F932F930E947F\r\n\
:1047900018068CE397E00E947F0580E297E00E9474\r\n\
:1047A0007F05C6FB882780F91F928F932DE137E0A4\r\n\
:1047B0003F932F930E9418068BE197E00E947F059C\r\n\
:1047C00083E197E00E947F05C7FBCC27C0F91F92C9\r\n\
:1047D000CF9380E197E09F938F930E9418068EE01D\r\n\
:1047E00097E00E947F058DB79EB74C960FB6F89460\r\n\
:1047F0009EBF0FBE8DBF04C081E796E00E947F057B\r\n\
:10480000C1E0B8C08091AB01C82FC17080FF09C062\r\n\
:104810008CE29AE00E947F058091AB01817F8E7FC0\r\n\
:1048200044C080E29AE00E947F058091AB018160E4\r\n\
:104830008093AB01E5CF8091AB0181FBCC27C0F920\r\n\
:1048400091E0C927C0FB81F98093AB01CC2319F01B\r\n\
:1048500083E19AE025C085E09AE0D0CF8091AB015A\r\n\
:1048600082FBCC27C0F991E0C927C0FB82F9809375\r\n\
:10487000AB01CC2319F086EF99E012C086EE99E0E7\r\n\
:10488000BDCF8091AB0183FBCC27C0F991E0C92754\r\n\
:10489000C0FB83F98093AB01CC2351F08AED99E002\r\n\
:1048A0000E947F058091AB0181608093AB0162C063\r\n\
:1048B0008DEC99E0A3CF8EEB99E00E947F0586E90D\r\n\
:1048C00099E00E947F0584E699E00E947F0587E3D6\r\n\
:1048D00099E00E947F0588EE98E00E947F0589EBB1\r\n\
:1048E00098E08CCF8BEA98E00E947F050E947D0EB5\r\n\
:1048F0001F928F9381E998E09F938F930E941806EF\r\n\
:1049000080910B011F928F938AE798E09F938F937A\r\n\
:104910000E941806809150011F928F9387E698E0BD\r\n\
:104920009F938F930E9418068091AD019091AE01E4\r\n\
:10493000A091AF01B091B001BF93AF939F938F93BC\r\n\
:1049400083E598E09F938F930E9418068DB79EB7DA\r\n\
:1049500042960FB6F8949EBF0FBE8DBF51CF80E038\r\n\
:1049600001C08D510E944A224BCF81E598E00E9400\r\n\
:104970007F05C0E08C2FCF91089580E0089580E0FE\r\n\
:104980000895CF93C82F8091BB01813071F020F042\r\n\
:10499000823009F448C03FC1A0910C01B0910D01D3\r\n\
:1049A0008C91823209F039C107C0A0910C01B091FD\r\n\
:1049B0000D018C91823249F48C2F0E94BD2481110B\r\n\
:1049C0002FC08C2F0E9468222CC08C2F0E94BF24E5\r\n\
:1049D000811126C0C431E1F070F4CB3081F0C031D8\r\n\
:1049E000D1F40E9412218DE396E00E947F0582E0BF\r\n\
:1049F0008093BB0115C0C93259F0C83361F48AE411\r\n\
:104A000096E00E947F0581E496E00E947F0508C041\r\n\
:104A10001092BB0104C18BE396E00E947F05FFC0AA\r\n\
:104A200081E08170FEC0C43228F5CE3108F0C1C0EB\r\n\
:104A3000CB30A1F1D0F4C73009F0D3C08EE1809320\r\n\
:104A4000130182E3809312018AE08093110184E1D3\r\n\
:104A50008093100188E080930F0188E280930E011B\r\n\
:104A600081EE94E00E947F05BFC0C33149F1C4319B\r\n\
:104A7000C1F0B7C0CB3409F4A9C028F4C93289F019\r\n\
:104A8000C83361F0AEC0C13509F49EC0C23509F427\r\n\
:104A900099C0CE3409F0A5C06AE09EC00E941221E0\r\n\
:104AA000A3C08091BA01882319F01092BA019CC06A\r\n\
:104AB0008EEE94E00E947F0581E08093BB01B1C03F\r\n\
:104AC00088EC94E00E947F0586EB94E00E947F05CD\r\n\
:104AD000809113011F928F9383EB94E09F938F93A8\r\n\
:104AE0000E94180681EB94E00E947F058FE994E014\r\n\
:104AF0000E947F05809112011F928F938CE994E0B0\r\n\
:104B00009F938F930E9418068AE994E00E947F0584\r\n\
:104B10008BE894E00E947F05809111011F928F9392\r\n\
:104B200088E894E09F938F930E94180686E894E0AB\r\n\
:104B30000E947F0585E794E00E947F058091100127\r\n\
:104B40001F928F9382E794E09F938F930E941806A1\r\n\
:104B500080E794E00E947F058BE594E00E947F054A\r\n\
:104B600080910F011F928F9388E594E09F938F931C\r\n\
:104B70000E94180686E594E00E947F058FE394E08A\r\n\
:104B80000E947F0580910E011F928F938CE394E029\r\n\
:104B90009F938F930E9418068AE394E00E947F05FA\r\n\
:104BA0008DB79EB748960FB6F8949EBF0FBE8DBFC7\r\n\
:104BB0001BC0CE51EC2FF0E0E85DFE4F808180936A\r\n\
:104BC000BA0112C061E003C061E006C06AE08091F2\r\n\
:104BD000BA010E94292108C08091BA010E94CC210B\r\n\
:104BE00003C08FED94E013C08091BA01882369F06F\r\n\
:104BF0001F928F9389ED94E09F938F930E941806E4\r\n\
:104C00000F900F900F900F9004C086ED94E00E94DB\r\n\
:104C10007F0581E006C01092BB0180E002C080E009\r\n\
:104C200000CFCF91089504D06894B1118DC008953C\r\n\
:104C300070D088F09F5790F0B92F9927B751A0F006\r\n\
:104C4000D1F0660F771F881F991F1AF0BA95C9F720\r\n\
:104C500012C0B13081F077D0B1E0089574C0672FF1\r\n\
:104C6000782F8827B85F39F0B93FCCF386957795D0\r\n\
:104C70006795B395D9F73EF49095809570956195B9\r\n\
:104C80007F4F8F4F9F4F0895E89409C097FB3EF4E4\r\n\
:104C900090958095709561957F4F8F4F9F4F992389\r\n\
:104CA000A9F0F92F96E9BB279395F6958795779507\r\n\
:104CB0006795B795F111F8CFFAF4BB0F11F460FFC7\r\n\
:104CC0001BC06F5F7F4F8F4F9F4F16C0882311F01F\r\n\
:104CD00096E911C0772321F09EE8872F762F05C033\r\n\
:104CE000662371F096E8862F70E060E02AF09A95CE\r\n\
:104CF000660F771F881FDAF7880F9695879597F9C3\r\n\
:104D0000089557FD9058440F551F59F05F3F71F0BB\r\n\
:104D10004795880F97FB991F61F09F3F79F0879522\r\n\
:104D20000895121613061406551FF2CF4695F1DFAB\r\n\
:104D300008C0161617061806991FF1CF869571053B\r\n\
:104D4000610508940895E894BB2766277727CB016F\r\n\
:104D500097F908950AD080C071D028F076D018F065\r\n\
:104D6000952309F062C067C0EFCFCBDFA8F399238A\r\n\
:104D7000D9F35523C9F3950F50E0551FAA27EE2705\r\n\
:104D8000FF27BB2700240894679520F4E20FF31F48\r\n\
:104D9000B41F0A1E220F331F441FAA1F6695A9F7CE\r\n\
:104DA000779530F4F30FB41F0A1E121E08F46395B2\r\n\
:104DB000330F441FAA1F221F769599F7879520F479\r\n\
:104DC000B40F0A1E121E631F440FAA1F221F331F97\r\n\
:104DD0008695A9F7862F712D602D11249F5750407D\r\n\
:104DE0008AF0E1F088234AF0EE0FFF1FBB1F661F19\r\n\
:104DF000771F881F91505040A9F79E3F510570F0D2\r\n\
:104E000014C0A2CF5F3FECF3983EDCF38695779514\r\n\
:104E10006795B795F795E7959F5FC1F7FE2B880FCC\r\n\
:104E2000911D9695879597F9089597F99F6780E862\r\n\
:104E300070E060E008959FEF80EC089500240A94EC\r\n\
:104E40001616170618060906089500240A94121665\r\n\
:104E50001306140605060895092E0394000C11F498\r\n\
:104E6000882352F0BB0F40F4BF2B11F460FF04C045\r\n\
:104E70006F5F7F4F8F4F9F4F08950024552704C0C9\r\n\
:104E8000080E591F880F991F009729F0769567958E\r\n\
:104E9000B8F37105B9F7802D952F0895991B79E026\r\n\
:104EA00004C0991F961708F0961B881F7A95C9F7BA\r\n\
:104EB0008095089597FB072E16F4009407D077FD90\r\n\
:104EC00009D00E94742707FC05D03EF49095819587\r\n\
:104ED0009F4F0895709561957F4F0895EE0FFF1FC6\r\n\
:104EE0000590F491E02D0994AA1BBB1B51E107C06A\r\n\
:104EF000AA1FBB1FA617B70710F0A61BB70B881F6A\r\n\
:104F0000991F5A95A9F780959095BC01CD010895F8\r\n\
:104F1000F999FECF92BD81BDF89A992780B5089581\r\n\
:104F2000A8E1B0E042E050E00C94AB27262FF999BD\r\n\
:104F3000FECF1FBA92BD81BD20BD0FB6F894FA9A7C\r\n\
:104F4000F99A0FBE019608950E949627272F0C9478\r\n\
:104F50009727DC01CB01FC01F999FECF06C0F2BD19\r\n\
:104F6000E1BDF89A319600B40D9241505040B8F727\r\n\
:064F70000895F894FFCF44\r\n\
:104F760005470738081508E107AE0701A10128080B\r\n\
:104F8600140A321E3F4D362067021A02E401C4019C\r\n\
:104F96005001690182019B0101020304050607080D\r\n\
:024FA600090000\r\n\
";
}
